@@ -5,7 +5,7 @@ use XML::Simple;
 use LWP::UserAgent;
 use WWW::FMyLife::Item;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 has 'username' => ( is => 'rw', isa => 'Str' );
 has 'password' => ( is => 'rw', isa => 'Str' );
@@ -106,7 +106,20 @@ sub flop_month {
 
 sub last {
     my ( $self, $opts ) = @_;
-    my @items = $self->_parse_options( $opts, 'last' );
+    my $type = 'last';
+
+    if ( ref $opts eq 'HASH' && $opts->{'category'} ) {
+        $type = $opts->{'category'};
+    }
+
+    my @items = $self->_parse_options( $opts, $type );
+    return @items;
+}
+
+sub get_id {
+    my ( $self, $id, $opts ) = @_;
+    $opts->{'page'} = '/nocomment';
+    my @items = $self->_parse_options( $opts, $id  );
     return @items;
 }
 
@@ -141,6 +154,11 @@ sub _parse_options {
 
     $xml || return;
 
+    if ( my $id = $xml->{'items'}{'item'}{'id'} ) {
+        $xml->{'items'}{'item'} = { $id => $xml{'items'}{'item'} };
+        $xml->{'pages'}         = 1;
+    }
+
     $self->pages( $xml->{'pages'} );
 
     my @items = $types{$as}->($xml);
@@ -242,7 +260,7 @@ WWW::FMyLife - Obtain FMyLife.com anecdotes via API
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SYNOPSIS
 
